@@ -232,6 +232,10 @@ foreach my $f (keys %{$pkg}) {
     }
 }
 
+if (not debarch_eq('all', $fields->{'Architecture'}) && $ENV{DEB_HOST_ARCH_VARIANT}) {
+    $fields->{"Architecture-Variant"} = $ENV{DEB_HOST_ARCH_VARIANT};
+}
+
 # Scan fields of dpkg-parsechangelog
 foreach my $f (keys %{$changelog}) {
     my $v = $changelog->{$f};
@@ -399,7 +403,7 @@ if ($stdout) {
     my $sversion = $fields->{'Version'};
     $sversion =~ s/^\d+://;
     $forcefilename //= sprintf('%s_%s_%s.%s', $fields->{'Package'}, $sversion,
-                               $fields->{'Architecture'}, $pkg_type);
+                               $fields->{'Architecture-Variant'} || $fields->{'Architecture'}, $pkg_type);
 
     my %fileprop;
     foreach my $f (qw(Section Priority)) {
@@ -424,6 +428,7 @@ if ($stdout) {
             ($file->{package} eq $fields->{'Package'}) &&
             ($file->{package_type} eq $pkg_type) &&
             (debarch_eq($file->{arch}, $fields->{'Architecture'}) ||
+             debarch_eq($file->{arch}, $fields->{'Architecture-Variant'}) ||
              debarch_eq($file->{arch}, 'all'))) {
             $dist->del_file($file->{filename});
         }
@@ -431,6 +436,7 @@ if ($stdout) {
 
     my %fileattrs;
     $fileattrs{automatic} = 'yes' if $fields->{'Auto-Built-Package'};
+    $fileattrs{architecture} = $fields->{'Architecture'};
 
     $dist->add_file($forcefilename, @fileprop{qw(section priority)}, %fileattrs);
     $dist->save("$fileslistfile.new");
